@@ -44,6 +44,48 @@ struct iio_channel_info {
 	unsigned location;
 };
 
+#define _IIO_GETU(__data, __idx, __size, __shift) \
+    (((guint##__size) (((const guint8 *) (__data))[__idx])) << (__shift))
+
+#define _IIO_READ_UINT32_BE(data)       (_IIO_GETU (data, 0, 32, 24) | \
+                                         _IIO_GETU (data, 1, 32, 16) | \
+                                         _IIO_GETU (data, 2, 32,  8) | \
+                                         _IIO_GETU (data, 3, 32,  0))
+
+#define _IIO_READ_UINT32_LE(data)       (_IIO_GETU (data, 3, 32, 24) | \
+                                         _IIO_GETU (data, 2, 32, 16) | \
+                                         _IIO_GETU (data, 1, 32,  8) | \
+                                         _IIO_GETU (data, 0, 32,  0))
+
+static inline guint32
+iio_readu32 (struct iio_channel_info *info, const guint8 * data)
+{
+	if (info->be)
+		return _IIO_READ_UINT32_BE (data + info->location);
+	return _IIO_READ_UINT32_LE(data + info->location);
+}
+
+#define _IIO_GET(__data, __idx, __size, __shift) \
+    (((guint##__size) (((const guint8 *) (__data))[__idx])) << (__shift))
+
+#define _IIO_READ_INT32_BE(data)       (_IIO_GET (data, 0, 32, 24) | \
+                                        _IIO_GET (data, 1, 32, 16) | \
+                                        _IIO_GET (data, 2, 32,  8) | \
+                                        _IIO_GET (data, 3, 32,  0))
+
+#define _IIO_READ_INT32_LE(data)       (_IIO_GET (data, 3, 32, 24) | \
+                                        _IIO_GET (data, 2, 32, 16) | \
+                                        _IIO_GET (data, 1, 32,  8) | \
+                                        _IIO_GET (data, 0, 32,  0))
+
+static inline gint32
+iio_read32 (struct iio_channel_info *info, const gint8 * data)
+{
+	if (info->be)
+		return _IIO_READ_INT32_BE (data + info->location);
+	return _IIO_READ_INT32_LE(data + info->location);
+}
+
 static char *
 iioutils_break_up_name (const char *name)
 {
@@ -177,7 +219,8 @@ iioutils_get_param_float (float      *output,
 		fclose (sysfsfp);
 	} else {
 		ret = -errno;
-		g_warning ("Failed to read float from %s", filename);
+		if (ret != -ENOENT)
+			g_warning ("Failed to read float from %s: %s", filename, g_strerror (-ret));
 	}
 
 	g_free (filename);
@@ -474,7 +517,7 @@ size_from_channelarray (iio_channel_info **channels,
  **/
 void
 process_scan_1 (char              *data,
-    BufferDrvData        *buffer_data,
+		BufferDrvData        *buffer_data,
 		const char        *ch_name,
 		int               *ch_val,
 		gdouble           *ch_scale,
@@ -492,15 +535,17 @@ process_scan_1 (char              *data,
 			/* only a few cases implemented so far */
 		case 4:
 			if (!buffer_data->channels[k]->is_signed) {
-				guint32 val = *(guint32 *) (data + buffer_data->channels[k]->location);
+				guint32 val = iio_readu32(buffer_data->channels[k], (guint8 *) data);
 				val = val >> buffer_data->channels[k]->shift;
-				if (buffer_data->channels[k]->bits_used < 32) val &= ((guint32) 1 << buffer_data->channels[k]->bits_used) - 1;
+				if (buffer_data->channels[k]->bits_used < 32)
+					val &= ((guint32) 1 << buffer_data->channels[k]->bits_used) - 1;
 				*ch_val = (int) val;
 				*ch_present = TRUE;
 			} else {
-				gint32 val = *(gint32 *) (data + buffer_data->channels[k]->location);
+				gint32 val = iio_read32(buffer_data->channels[k], (gint8 *) data);
 				val = val >> buffer_data->channels[k]->shift;
-				if (buffer_data->channels[k]->bits_used < 32) val &= ((guint32) 1 << buffer_data->channels[k]->bits_used) - 1;
+				if (buffer_data->channels[k]->bits_used < 32)
+					val &= ((guint32) 1 << buffer_data->channels[k]->bits_used) - 1;
 				val = (gint32) (val << (32 - buffer_data->channels[k]->bits_used)) >> (32 - buffer_data->channels[k]->bits_used);
 				*ch_val = (int) val;
 				if (buffer_data->channels[k]->scale)
